@@ -295,17 +295,6 @@ sub _set_vars {
     }
 }
 
-#deprecated ->resolve & traverse
-=head2 __get_objects_by_path [path], $session
-
-Check if exist method in $path and return $self or undef
-
-=cut
-
-sub __get_objects_by_path {
-    my $self = shift;
-    return;
-}
 1;
 __DATA__
 
